@@ -1,7 +1,7 @@
 """Fake Preseem Model implementation."""
 import copy
 import time
-from uuid import uuid4, UUID
+from uuid import uuid4
 
 import grpc
 from preseem.preseem_model import BaseModelObject
@@ -10,6 +10,7 @@ from preseem.preseem_model import BaseModelObject
 class FakePreseemModel:
     _companies = {}  # company_uuid to Company object
     _elements = {}  # company_uuid to {element_uuid to Element object}
+    _accounts = {}  # company_uuid to {account_uuid to Account object}
     _packages = {}  # company_uuid to {package_uuid to Package object}
     _sites = {}  # company_uuid to {site_uuid to Site object}
     _elem_disc = {}  # company_uuid to {uuid to ElementDiscovery object}
@@ -39,7 +40,7 @@ class FakePreseemModel:
         try:
             for obj in await other.Company.List():
                 FakePreseemModel._companies[obj.uuid] = obj
-        except grpc.RpcError as err:  # likely permissions, fake this
+        except grpc.RpcError:  # likely permissions, fake this
             FakePreseemModel._companies[company_uuid] = other.Company(uuid=company_uuid)
         for obj in await other.Element.List(company_uuid=company_uuid):
             elems = FakePreseemModel._elements.get(company_uuid)
@@ -214,6 +215,65 @@ class FakePreseemModel:
                             disc.updated_at = time.time()
                         setattr(disc, attr, val)
 
+    class Account(BaseModelObject):
+
+        @classmethod
+        async def Create(cls, **kwargs):
+            company_uuid = kwargs.get('company_uuid')
+            assert company_uuid
+            company = FakePreseemModel._companies[company_uuid]
+            obj = cls(**FakePreseemModel._new_attrs(),
+                      company_uuid=company.uuid,
+                      source=kwargs.get('source'),
+                      source_id=kwargs.get('source_id'),
+                      type=kwargs.get('type'),
+                      status=kwargs.get('status'),
+                      company_name=kwargs.get('company_name'),
+                      first_name=kwargs.get('first_name'),
+                      last_name=kwargs.get('last_name'))
+            accounts = FakePreseemModel._accounts.get(company.uuid)
+            if accounts is None:
+                accounts = FakePreseemModel._accounts[company_uuid] = {}
+            accounts[obj.uuid] = obj
+            return copy.deepcopy(obj)
+
+        @classmethod
+        async def List(cls, **kwargs):
+            company_uuid = kwargs.get('company_uuid')
+            assert company_uuid
+            # the real impl returns empty list if the company doesn't exist
+            return [
+                copy.deepcopy(x)
+                for x in (FakePreseemModel._accounts.get(company_uuid) or {}).values()
+            ]
+
+        @classmethod
+        async def Delete(cls, **kwargs):
+            company_uuid = kwargs.get('company_uuid')
+            uuid = kwargs.get('uuid')
+            accounts = FakePreseemModel._accounts[company_uuid]
+            if accounts:
+                account = accounts.get(uuid)
+                if account:
+                    del accounts[uuid]
+
+        @classmethod
+        async def Update(cls, **kwargs):
+            company_uuid = kwargs.get('company_uuid')
+            uuid = kwargs.get('uuid')
+            accounts = FakePreseemModel._accounts[company_uuid]
+            if accounts:
+                account = accounts.get(uuid)
+                for attr, val in kwargs.items():
+                    if attr == 'company_uuid' or attr == 'uuid':
+                        continue
+                    elif attr == 'inactive' and val is True:
+                        FakePreseemModel._set_inactive(account)
+                    else:
+                        if getattr(account, attr) != val:
+                            account.updated_at = time.time()
+                        setattr(account, attr, val)
+
     class Package(BaseModelObject):
 
         @classmethod
