@@ -28,7 +28,7 @@ import grpc
 
 from preseem_grpc_model import metrics_pb2, metrics_pb2_grpc
 from preseem_grpc_model import network_metadata_pb2, network_metadata_pb2_grpc
-from preseem_grpc_model import company_configs_pb2, company_configs_pb2_grpc
+from preseem_protobuf.config import company_configs_pb2, company_configs_pb2_grpc
 
 
 class ConfigType():
@@ -154,8 +154,8 @@ class PreseemGrpcClient(object):
         for ctname, ctid in company_configs_pb2.Type.items():
             try:
                 cn = ctname.lower()
-                pmod = import_module(f'preseem_grpc_model.{cn}_pb2')
-                gmod = import_module(f'preseem_grpc_model.{cn}_pb2_grpc')
+                pmod = import_module(f'preseem_protobuf.config.{cn}_pb2')
+                gmod = import_module(f'preseem_protobuf.config.{cn}_pb2_grpc')
                 ct = self.config_types[ctid] = ConfigType(cn, cn.replace('_', ''), ctid,
                                                           pmod, gmod)
                 # assume naming conventions for the operations
