@@ -5,15 +5,25 @@ import logging
 # STM-9317 suppress warnings until STM-5490 is fixed.
 import warnings
 from cryptography.utils import CryptographyDeprecationWarning
+
 warnings.filterwarnings("ignore", category=CryptographyDeprecationWarning)
 
 import asyncssh
+
 asyncssh.set_log_level(logging.ERROR)
 
+
 class SshClient():
     """Helper class for a SSH client.  User is responsible for retry/errors."""
-    def __init__(self, host, port=None, username=None, password=None,
-                 tunnel=None, init_wait=0, verbose=0):
+
+    def __init__(self,
+                 host,
+                 port=None,
+                 username=None,
+                 password=None,
+                 tunnel=None,
+                 init_wait=0,
+                 verbose=0):
         self.host = host
         self.port = port or 22
         self.username = username
@@ -28,10 +38,14 @@ class SshClient():
     async def _open(self):
         if self._conn is None:
             try:
-                self._conn = await asyncio.wait_for(asyncssh.connect(self.host, port=self.port, known_hosts=None,
-                                                    tunnel=self._tun,
-                                                    username=self.username,
-                                                    password=self.password), timeout=5.0)
+                self._conn = await asyncio.wait_for(asyncssh.connect(
+                    self.host,
+                    port=self.port,
+                    known_hosts=None,
+                    tunnel=self._tun,
+                    username=self.username,
+                    password=self.password),
+                                                    timeout=5.0)
             except Exception as err:
                 logging.warning('Error connecting to %s: %s', self.host, err)
                 raise
@@ -46,7 +60,12 @@ class SshClient():
         """Create a new client tunnelled through this one."""
         if self._conn is None:
             await self._open()
-        return SshClient(host, port, username=username, password=password, tunnel=self._conn, verbose=self.verbose)
+        return SshClient(host,
+                         port,
+                         username=username,
+                         password=password,
+                         tunnel=self._conn,
+                         verbose=self.verbose)
 
     async def cmd(self, cmd, timeout=5.0, delimiter=None, term_type=None):
         """Send a command.  The response is returned."""
@@ -54,7 +73,8 @@ class SshClient():
             await self._open()
         if self.stdin is None:
             try:
-                self.stdin, self.stdout, self.stderr = await self._conn.open_session(term_type=term_type)
+                self.stdin, self.stdout, self.stderr = await self._conn.open_session(
+                    term_type=term_type)
                 if not delimiter:
                     # this sometimes helps "kick" a connection so the first
                     # command works when it wouldn't otherwise.  saw this with
@@ -65,11 +85,13 @@ class SshClient():
                     await asyncio.sleep(self.init_wait)
                     await self.stdout.read(2048)
                 else:
-                    r = await asyncio.wait_for(self.stdout.readuntil(delimiter), timeout=timeout)
+                    r = await asyncio.wait_for(self.stdout.readuntil(delimiter),
+                                               timeout=timeout)
             except asyncio.CancelledError:
                 raise
             except Exception as err:
-                logging.warning('Error establishing session to %s: %s'.format(self.host, err))
+                logging.warning('Error establishing session to %s: %s'.format(
+                    self.host, err))
                 raise
 
         if self.verbose > 2:
